@@ -1,14 +1,54 @@
 ###
-###
 ### Ramsay, Hooker & Graves (2009)
 ### Functional Data Analysis with R and Matlab (Springer)
+###
+
+#  Remarks and disclaimers
+
+#  These R commands are either those in this book, or designed to 
+#  otherwise illustrate how R can be used in the analysis of functional
+#  data.  
+#  We do not claim to reproduce the results in the book exactly by these 
+#  commands for various reasons, including:
+#    -- the analyses used to produce the book may not have been
+#       entirely correct, possibly due to coding and accuracy issues
+#       in the functions themselves 
+#    -- we may have changed our minds about how these analyses should be 
+#       done since, and we want to suggest better ways
+#    -- the R language changes with each release of the base system, and
+#       certainly the functional data analysis functions change as well
+#    -- we might choose to offer new analyses from time to time by 
+#       augmenting those in the book
+#    -- many illustrations in the book were produced using Matlab, which
+#       inevitably can imply slightly different results and graphical
+#       displays
+#    -- we may have changed our minds about variable names.  For example,
+#       we now prefer "yearRng" to "yearRng" for the weather data.
+#    -- three of us wrote the book, and the person preparing these scripts
+#       might not be the person who wrote the text
+#  Moreover, we expect to augment and modify these command scripts from time
+#  to time as we get new data illustrating new things, add functionality
+#  to the package, or just for fun.
+
 ###
 ### ch. 8.  Registration: Aligning Features
 ###         for Samples of Curves
 ###
 
+#  load the fda package
+
 library(fda)
 
+#  display the data files associated with the fda package
+
+data(package='fda')
+
+#  start the HTML help system if you are connected to the Internet, in
+#  order to open the R-Project documentation index page in order to obtain
+#  information about R or the fda package.
+
+help.start()
+
 ##
 ## Section 8.1 Amplitude and Phase Variation
 ##
@@ -91,6 +131,8 @@ eigvecampli = svd(DpGampli)$d^2
 ## Section 8.2 Time-Warping Functions and Registration
 ##
 
+#  ----------  Registration of the Berkeley female growth data  -----------
+
 #  Figure 8.3 requires landmark registration, and is set up below
 
 ##
@@ -118,17 +160,17 @@ ncasef = dim(hgtf)[2]
 #  Section 5.4.2.2  in the text.  To create it here, we copy
 #  relevant lines from the script file fdarm-ch05.R
 
-growbasis = with(growth, create.bspline.basis(norder=6, breaks=age))
+growbasis = create.bspline.basis(norder=6, breaks=age)
 Lfdobj    = 3          #  penalize curvature of acceleration
 lambda    = 10^(-0.5)  #  smoothing parameter
 cvecf     = matrix(0, growbasis$nbasis, ncol(growth$hgtf))
 dimnames(cvecf) = list(growbasis$names, dimnames(growth$hgtf)[[2]])
 
-growfd0      = fd(cvecf, growbasis)
+growfd0   = fd(cvecf, growbasis)
 growfdPar = fdPar(growfd0, Lfdobj, lambda)
 
-growthMon = with(growth, smooth.monotone(age, hgtf, growfdPar))
-hgtfhatfd  = growthMon$yhatfd
+growthMon = smooth.monotone(age, hgtf, growfdPar)
+hgtfhatfd = growthMon$yhatfd
 
 accelfdUN     = deriv.fd(hgtfhatfd, 2)
 accelmeanfdUN = mean(accelfdUN)
@@ -273,6 +315,24 @@ lines(agefine,  agefine, lty=2, lwd=1.5)
 text(PGSctrmean+0.1, warpmatLM[61,7]+0.2, "o", lwd=2)
 par(op)
 
+#  Comparing unregistered to landmark registered curves
+
+AmpPhasList = AmpPhaseDecomp(accelfdUN, accelfdLM, warpfdLM, c(3,18))
+MS.amp      = AmpPhasList$MS.amp
+MS.pha      = AmpPhasList$MS.pha
+RSQRLM      = AmpPhasList$RSQR
+CLM         = AmpPhasList$C
+
+print(paste("Total MS =",     round(MS.amp+MS.pha,2), 
+            "Amplitude MS =", round(MS.amp,2),
+            "Phase MS =",     round(MS.pha,2)))
+            
+#  [1] "Total MS = 7.06 Amplitude MS = 2.12 Phase MS = 4.95"
+
+print(paste("R-squared =", round(RSQRLM,3), ",  C =", round(CLM,3)))
+
+#  "R-squared = 0.7 ,  C = 0.984"
+
 ##
 ##  Section 8.4: Continuous registration
 ##
@@ -291,14 +351,12 @@ WfdParCR  = fdPar(Wfd0CR, 1, lambdaCR)
 registerlistCR = register.fd(accelmeanfdLM, accelfdLM, WfdParCR)
 
 accelfdCR = registerlistCR$regfd
-warpfdCR  = registerlistCR$warpfd
 WfdCR     = registerlistCR$Wfd
 
-plot(warpfdCR)
-
 #  plot landmark and continuously registered curves for the
 #  first 10 children
 
+accelmeanfdLM10 = mean(accelfdLM[children])
 accelmeanfdCR10 = mean(accelfdCR[children])
 
 op = par(mfrow=c(2,1))
@@ -351,22 +409,24 @@ lines(accelmeanfdUN, lwd=1.5, lty=2)
 ## Section 8.5 A Decomposition into Amplitude and Phase Sums of Squares
 ##
 
-#  Comparing unregistered to landmark registered curves
-
-AmpPhasList = AmpPhaseDecomp(accelfdUN, accelfdLM, warpfdLM)
-RSQRLM      = AmpPhasList$RSQR
-CLM         = AmpPhasList$C
-
-print(paste("R-squared =", round(RSQRLM,3), ",  C =", round(CLM,3)))
-
 #  Comparing landmark to continuously registered curves
 
-AmpPhasList = AmpPhaseDecomp(accelfdLM, accelfdCR, warpfdCR)
+AmpPhasList = AmpPhaseDecomp(accelfdLM, accelfdCR, warpfdCR, c(3,18))
+MS.amp      = AmpPhasList$MS.amp
+MS.pha      = AmpPhasList$MS.pha
 RSQRCR      = AmpPhasList$RSQR
 CCR         = AmpPhasList$C
 
+print(paste("Total MS =",     round(MS.amp+MS.pha,2), 
+            "Amplitude MS =", round(MS.amp,2),
+            "Phase MS =",     round(MS.pha,2)))
+            
+#  "Total MS = 1.5 Amplitude MS = 1.6 Phase MS = -0.1"
+
 print(paste("R-squared =", round(RSQRCR,3), ",  C =", round(CCR,3)))
 
+#  "R-squared = -0.067 ,  C = 1.001"
+
 ##
 ## 8.6 Registering the Chinese Handwriting Data
 ##
@@ -376,6 +436,7 @@ print(paste("R-squared =", round(RSQRCR,3), ",  C =", round(CCR,3)))
 ##
 ## 8.7 Details for Functions landmarkreg and register.fd
 ##
+
 help(landmarkreg)
 help(register.fd)
 
